==> schemacrawler-14.17.05-sources.jar: schemacrawler/tools/executable/CommandProvider.java <==
/*
========================================================================
SchemaCrawler
http://www.schemacrawler.com
Copyright (c) 2000-2018, Sualeh Fatehi <sualeh@hotmail.com>.
All rights reserved.
------------------------------------------------------------------------

SchemaCrawler is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

SchemaCrawler and the accompanying materials are made available under
the terms of the Eclipse Public License v1.0, GNU General Public License
v3 or GNU Lesser General Public License v3.

You may elect to redistribute this code under any of these licenses.

The Eclipse Public License is available at:
http://www.eclipse.org/legal/epl-v10.html

The GNU General Public License v3 and the GNU Lesser General Public
License v3 are available at:
http://www.gnu.org/licenses/

========================================================================
*/
package schemacrawler.tools.executable;


import schemacrawler.schemacrawler.SchemaCrawlerException;
import schemacrawler.schemacrawler.SchemaCrawlerOptions;
import schemacrawler.tools.options.OutputOptions;

public interface CommandProvider
{

  Executable configureNewExecutable(SchemaCrawlerOptions schemaCrawlerOptions,
                                    OutputOptions outputOptions)
    throws SchemaCrawlerException;

  String getCommand();

  String getHelpAdditionalText();

  String getHelpResource();

}

==> schemacrawler-14.21.01-sources.jar: schemacrawler/tools/executable/CommandProvider.java <==
/*
========================================================================
SchemaCrawler
http://www.schemacrawler.com
Copyright (c) 2000-2018, Sualeh Fatehi <sualeh@hotmail.com>.
All rights reserved.
------------------------------------------------------------------------

SchemaCrawler is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

SchemaCrawler and the accompanying materials are made available under
the terms of the Eclipse Public License v1.0, GNU General Public License
v3 or GNU Lesser General Public License v3.

You may elect to redistribute this code under any of these licenses.

The Eclipse Public License is available at:
http://www.eclipse.org/legal/epl-v10.html

The GNU General Public License v3 and the GNU Lesser General Public
License v3 are available at:
http://www.gnu.org/licenses/

========================================================================
*/
package schemacrawler.tools.executable;


import java.util.Collection;

import schemacrawler.schemacrawler.SchemaCrawlerException;
import schemacrawler.schemacrawler.SchemaCrawlerOptions;
import schemacrawler.tools.iosource.InputResource;
import schemacrawler.tools.options.OutputOptions;

public interface CommandProvider
{

  Executable configureNewExecutable(String command,
                                    SchemaCrawlerOptions schemaCrawlerOptions,
                                    OutputOptions outputOptions)
    throws SchemaCrawlerException;

  InputResource getHelp();

  Collection<String> getSupportedCommands();

  boolean supportsCommand(String command,
                          SchemaCrawlerOptions schemaCrawlerOptions,
                          OutputOptions outputOptions);

}
